NAME

DB::Hooks - Hooks for perl debugger

Possible options

undef - configures visible representation for 'undef' during dumps.

Possible events

load - after module is compiled goto - after 'goto' was executed call - before calling a subroutine return - before returning from a subroutine Next events occur only during 'interact' and when additionally: trace - $DB::trace is true trap - $DB::trap configured for that file:line stop - DB::state('single') is true binteract, interact, ainteract - 'trap' and 'stop' handlers did not cancel interaction OR $DB::signal is true

User defined events.

Debugger verbosity

DB::state( 'ddd' )

&64 - shows when context is stored and restored

&32 - display the information about: what events were emitted what expressions were evaluated in user context during 'process' state of a debug debugging for the next call depending on DB::state( 'dd' ) what callbacks were run during 'process' and finished when 'dbcall' (call to the debugger) happened and who called it when 'dbcall' finished. Start and stop info lines are marked by 'random' the next value of $DB::single when nested debugger was destroyed

&16 - display information when debugger is created/destroyed with the information about its state. Also displays messages when compilation was started/finished. &8 - track reads to DB::state &4 - track writes to DB::state &2 - track subroutine calls &1 - enable basic messages from debugger display which additional debugger modules are loaded display info from debugger commands

DB::flags displayed during debugging debugger: s:0 t:0 i:0 c:1

"s:$DB::single t:$DB::trace i:$DB::instance c:".@DB::state;

s -- step-by-step debugging enabled or not. t -- tracing enabled or note. i -- current debugger instance. c -- number of contexts. TODO? Should we name it d -- number of debuggers.

AUTHOR

Eugen Konkov <debugger@konkov.top>

COPYRIGHT

Copyright (c) 2015-2026 Eugen Konkov

LICENSE

This module is distributed under the Perl Debugger Evaluation and Commercial License. See the LICENSE file included with this distribution.

1 POD Error

The following errors were encountered while parsing the POD:

Around line 43:

Unterminated D<...> sequence

Deleting unknown formatting code D<>